@@ -332,6 +332,9 @@ _gweather_info_request_done (GWeatherInfo *info,
 
     if (info->priv->requests_pending == NULL)
         g_signal_emit (info, gweather_info_signals[SIGNAL_UPDATED], 0);
+    else
+        g_debug ("Not emitting 'updated' as there are still %d requests pending",
+                 g_slist_length (info->priv->requests_pending));
 }
 
 /* it's OK to pass in NULL */
@@ -595,6 +598,8 @@ ref_session (void)
 	return g_object_ref (session);
 
     session = soup_session_new ();
+    g_object_set (G_OBJECT (session), SOUP_SESSION_USER_AGENT,
+                  "libgweather/" LIBGWEATHER_VERSION " (+https://gitlab.gnome.org/GNOME/libgweather/) ", NULL);
 
     cache = get_cache ();
     if (cache != NULL) {
@@ -1276,10 +1281,8 @@ gweather_info_get_sunset (GWeatherInfo *info)
  * Returns: (transfer none) (element-type GWeather.Info): list
  * of GWeatherInfo* objects for the forecast.
  * The list is owned by the 'info' object thus is alive as long
- * as the 'info'. This list is filled only when requested with
- * type FORECAST_LIST and if available for given location.
- * The 'update' property is the date/time when the forecast info
- * is used for.
+ * as the 'info'. The 'update' property is the date/time when the
+ * forecast info is used for.
  **/
 GSList *
 gweather_info_get_forecast_list (GWeatherInfo *info)
